#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 StateVar
version:              1.2.2
visibility:           public
id:                   StateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb
key:                  StateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb
license:              BSD-3-Clause
copyright:
    Copyright (C) 2014-2015 Edward A. Kmett, 2009-2021 Sven Panne

maintainer:           Sven Panne <svenpanne@gmail.com>
author:               Sven Panne and Edward Kmett
homepage:             https://github.com/haskell-opengl/StateVar
synopsis:             State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.

category:             Data
abi:                  e12e90a5367fc4bef774972f3db8d259
exposed:              True
exposed-modules:      Data.StateVar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/StateVar-1.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/StateVar-1.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/StateVar-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statevar
hs-libraries:         HSStateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb
depends:              base-4.18.2.1 stm-2.5.1.0 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html:         /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

